@CODE Region
Date: 07 25, 2001 9:20:04 AM

# CODE Region

The Code Zone may optionally contain a single CODE Region, which begins with the @CODE marker and optionally terminates with the @@CODE marker.

NLP++ code in the CODE Region is executed prior to any rule matching for the current pass.

The CODE Region may, in addition to NLP++ code syntax, incorporate CODE Actions, i.e., specialized functions that are constrained to the CODE Region.

The exitpass() function is useful for conditionally and immediately terminating the current pass, without executing any rules.

## See Also

CODE Zone

CODE Action